lidarwind.filters.Filtering
===========================

.. currentmodule:: lidarwind.filters

.. autoclass:: Filtering

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Filtering.__init__
      ~Filtering.get_radial_obs_comp
      ~Filtering.get_vertical_obs_comp
   
   

   
   
   